#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_HMSB_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_HMSB_HPP_INCLUDED

#include <boost/simd/reduction/include/functions/hmsb.hpp>

#endif
